@@ -64,18 +64,7 @@ else
     sudo -u $USER git clone -b $BRANCH https://${CREDENTIALS}@github.com/$REPO_OWNER/$REPO.git
 fi
 
-# Stop processes
-for f in `ls /tmp/${REPO}/${DEPLOY_TYPE}_*.cfg`
-do
-    FILENAME=$(basename $f)
-    if [ $FILENAME != "${DEPLOY_TYPE}_base.cfg" ]; then
-        # Calculate directory name. Also name of script.
-        FTMP=${FILENAME%.*}
-        THEDIR=$PREFIX-${FTMP//_/-}
-
-        sudo supervisorctl stop ${THEDIR}.gunicorn
-    fi    
-done
+sudo supervisorctl stop all
 
 # Create database. Safe to run even if database already exists.
 IS_NEW_DATABASE=0
@@ -88,11 +77,13 @@ if [ "$RESULT" == "" ]; then
 fi
 
 # Checkouts
-INDEX=0
+DJANGO_SITE_INDEX=0
 for f in `ls /tmp/${REPO}/${DEPLOY_TYPE}_*.cfg`
 do
     FILENAME=$(basename $f)
-    if [ $FILENAME != "${DEPLOY_TYPE}_base.cfg" ]; then
+    # ${DEPLOY_TYPE}_base_* and ${DEPLOY_TYPE}_constants_* files must be ignored.
+    if [[ $FILENAME != *_base_*.cfg ]] && [[ $FILENAME != *_constants_*.cfg ]]; then
+
         # Calculate directory name. Also name of script.
         FTMP=${FILENAME%.*}
         THEDIR=$PREFIX-${FTMP//_/-}
@@ -133,84 +124,81 @@ do
             sudo -u $USER ./bin/buildout -Nv -c $FILENAME
         fi
 
-        # Database setup on first loop
-        if [ $INDEX == 0 ]; then
-            if [ $IS_NEW_DATABASE -eq 1 ]; then
-                read -p "Create a superuser if prompted. Do not generate default content. [enter]" y
-                sudo -u $USER ./bin/$THEDIR syncdb
-	        else
-                # Some Jmbo apps only got South migrations at a later stage. Scenarios:
-                # 1. CT not in DB - migrate
-                # 2. CT in DB, 0001 migration does not exist - fake migrate 0001
-                # 3. CT in DB, 0001 migration exists - migrate
-                FAKE_MIGRATE=""
-                for APP in competition music; do 
-                    RESULT=`sudo -u $USER ./bin/$THEDIR dumpdata south | grep "\"app_label\": \"$APP\""`
-                    if [ "$RESULT" != "" ]; then
-                        # CT is in DB. Now check for 0001 migration.
-                        RESULT=`sudo -u $USER ./bin/$THEDIR dumpdata south | grep "\"app_name\": \"$APP\", \"migration\": \"0001_initial\""`
-                        if [ "$RESULT" == "" ]; then
-                            # Migration is not in db. Add to fake migrate list.
-                            FAKE_MIGRATE="$FAKE_MIGRATE $APP"
+        if [[ $FILENAME != *_common_*.cfg ]]; then
+
+            # Database setup on first loop
+            if [ $DJANGO_SITE_INDEX == 0 ]; then
+                if [ $IS_NEW_DATABASE -eq 1 ]; then
+                    read -p "Create a superuser if prompted. Do not generate default content. [enter]" y
+                    sudo -u $USER ./bin/$THEDIR syncdb
+    	        else
+                    # Some Jmbo apps only got South migrations at a later stage. Scenarios:
+                    # 1. CT not in DB - migrate
+                    # 2. CT in DB, 0001 migration does not exist - fake migrate 0001
+                    # 3. CT in DB, 0001 migration exists - migrate
+                    FAKE_MIGRATE=""
+                    for APP in competition music; do 
+                        RESULT=`sudo -u $USER ./bin/$THEDIR dumpdata south | grep "\"app_label\": \"$APP\""`
+                        if [ "$RESULT" != "" ]; then
+                            # CT is in DB. Now check for 0001 migration.
+                            RESULT=`sudo -u $USER ./bin/$THEDIR dumpdata south | grep "\"app_name\": \"$APP\", \"migration\": \"0001_initial\""`
+                            if [ "$RESULT" == "" ]; then
+                                # Migration is not in db. Add to fake migrate list.
+                                FAKE_MIGRATE="$FAKE_MIGRATE $APP"
+                            fi
                         fi
-                    fi
-                done
+                    done
 
-	            sudo -u $USER ./bin/$THEDIR syncdb --noinput                
+	                sudo -u $USER ./bin/$THEDIR syncdb --noinput                
 
-                # Appky fake migrations
-                for APP in $FAKE_MIGRATE; do 
-                    sudo -u $USER ./bin/$THEDIR migrate ${APP} 0001_initial --fake
-                done
+                    # Apply fake migrations
+                    for APP in $FAKE_MIGRATE; do 
+                        sudo -u $USER ./bin/$THEDIR migrate ${APP} 0001_initial --fake
+                    done
+                fi
+                sudo -u $USER ./bin/$THEDIR migrate
+                sudo -u $USER ./bin/$THEDIR load_photosizes
+                sudo -u $USER ./bin/$THEDIR loaddata ${APP_NAME}/fixtures/sites.json
             fi
-            sudo -u $USER ./bin/$THEDIR migrate
-            sudo -u $USER ./bin/$THEDIR load_photosizes
-            sudo -u $USER ./bin/$THEDIR loaddata ${APP_NAME}/fixtures/sites.json
+
+            sudo -u $USER rm -rf static
+            sudo -u $USER ./bin/$THEDIR collectstatic --noinput
+
+            # Cron entries
+            touch /tmp/acron
+            sudo -u $USER crontab -l > /tmp/acron
+            for COMMAND in report_naughty_words jmbo_publish; do
+                RESULT=`grep "${THEDIR} ${COMMAND}" /tmp/acron`
+                if [ "$RESULT" == "" ]; then
+                    echo "0 * * * * ${DEPLOY_DIR}/${THEDIR}/bin/${THEDIR} ${COMMAND}" >> /tmp/acron
+                fi
+            done
+            sudo -u $USER crontab /tmp/acron
+            rm /tmp/acron
+
+            let DJANGO_SITE_INDEX++
+        fi
+        
+        # Create nginx symlink if required
+        if [ -d ${DEPLOY_DIR}/${THEDIR}/nginx ]; then
+            sudo ln -s ${DEPLOY_DIR}/${THEDIR}/nginx/* /etc/nginx/sites-enabled/
         fi
 
-        sudo -u $USER rm -rf static
-        sudo -u $USER ./bin/$THEDIR collectstatic --noinput
-
-        # Cron entries
-        touch /tmp/acron
-        sudo -u $USER crontab -l > /tmp/acron
-        for COMMAND in report_naughty_words jmbo_publish; do
-            RESULT=`grep "${THEDIR} ${COMMAND}" /tmp/acron`
-            if [ "$RESULT" == "" ]; then
-                echo "0 * * * * ${DEPLOY_DIR}/${THEDIR}/bin/${THEDIR} ${COMMAND}" >> /tmp/acron
-            fi
-        done
-        sudo -u $USER crontab /tmp/acron
-        rm /tmp/acron
-
-        # Create nginx symlink if required
-        sudo ln -s ${DEPLOY_DIR}/${THEDIR}/nginx/gunicorn-${THEDIR}.conf /etc/nginx/sites-enabled/
-
         # Create supervisor symlink if required
-        sudo ln -s ${DEPLOY_DIR}/${THEDIR}/supervisor/gunicorn-${THEDIR}.conf /etc/supervisor/conf.d/
+        if [ -d ${DEPLOY_DIR}/${THEDIR}/supervisor ]; then
+            sudo ln -s ${DEPLOY_DIR}/${THEDIR}/supervisor/* /etc/supervisor/conf.d/
+        fi
 
-        let INDEX++
     fi
 done
 
 # Update supervisor
 sudo supervisorctl update
 
-# Start processes
-for f in `ls /tmp/${REPO}/${DEPLOY_TYPE}_*.cfg`
-do
-    FILENAME=$(basename $f)
-    if [ $FILENAME != "${DEPLOY_TYPE}_base.cfg" ]; then
-        # Calculate directory name. Also name of script.
-        FTMP=${FILENAME%.*}
-        THEDIR=$PREFIX-${FTMP//_/-}
-
-        sudo supervisorctl start ${THEDIR}.gunicorn
-    fi    
-done
-
 # Restart memcached
 sudo /etc/init.d/memcached restart
 
+sudo supervisorctl start all
+
 # Reload nginx
 sudo /etc/init.d/nginx reload
